fastavro.read
=============

.. autoclass:: fastavro._read_py.reader

.. autoclass:: fastavro._read_py.block_reader

.. autofunction:: fastavro._read_py.schemaless_reader

.. autofunction:: fastavro.is_avro
